@@ -8,18 +8,18 @@ from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.support.select import Select
 import unittest, time, logging, os, inspect
-from Base_Logging import Base_Logging
-from BrowserStack_Library import BrowserStack_Library
-from driverfactory import DriverFactory
+from .Base_Logging import Base_Logging
+from .BrowserStack_Library import BrowserStack_Library
+from .driverfactory import DriverFactory
 # from utils.Test_Rail import Test_Rail
 # from utils import Tesults
 from stop_test_exception_util import Stop_Test_Exception
-import remote_credentials
-import base_url_conf
-import screenshot_conf
-import Gif_Maker
+from . import remote_credentials
+from . import base_url_conf
+from . import screenshot_conf
+from . import Gif_Maker
 from datetime import datetime
-from Wrapit import Wrapit
+from .Wrapit import Wrapit
 
 
 class Borg:
